{% load static %}
<!-- Start FontAwesome CSS from aa-gdpr -->
<link rel="stylesheet" type="text/css" href="{% static 'aagdpr/ajax/libs/font-awesome/5.15.4/css/all.min.css' %}" integrity="sha512-1ycn6IcaQQ40/MKBW2W4Rhis/DbILU74C1vSrLJxCq57o941Ym01SwNsOMqvEBFlcgUa6xLiPY/NS5R+E6ztJQ=="/>
<!-- End FontAwesome CSS from aa-gdpr -->
