{% load static %}
<!-- Start X-editable CSS from aa-gdpr -->
<link rel="stylesheet" type="text/css" href="{% static 'aagdpr/ajax/libs/x-editable/1.5.1/css/bootstrap-editable.css' %}" integrity="sha512-e0rbO6UJET0zDdXOHjwc6D44UpeKumn7cU7XR/fa4S0/Jso0bZqcCqlIF6mtvcimMbf846mkv8aSWFnTwABr/g=="/>
<!-- End X-editable CSS from aa-gdpr -->
