{% load static %}
<!-- Start Bootstrap + jQuery js from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/jquery/3.6.0/jquery.min.js' %}" integrity="sha512-894YE6QWD5I59HgZOGReFYm4dnWc1Qt5NtvYSaNcOP+u1T9qYdvdihz0PPSiiqn/+/3e7Jo4EaG7TubfWGUrMQ=="></script>
<script src="{% static 'aagdpr/ajax/libs/twitter-bootstrap/3.4.1/js/bootstrap.min.js' %}" integrity="sha512-oBTprMeNEKCnqfuqKd6sbvFzmFQtlXS3e0C/RGFV0hD6QzhHV+ODfaQbAlmY6/q0ubbwlAM/nCJjkrgA3waLzg=="></script>
<!-- End Bootstrap + jQuery js from aa-gdpr -->
