{% load static %}
<!-- Start Datatables-js from aa-gdpr -->
<script type="application/javascript" src="{% static 'aagdpr/ajax/libs/datatables/1.10.21/js/jquery.dataTables.min.js' %}" integrity="sha512-BkpSL20WETFylMrcirBahHfSnY++H2O1W+UnEEO4yNIl+jI2+zowyoGJpbtk6bx97fBXf++WJHSSK2MV4ghPcg=="></script>
<script type="application/javascript" src="{% static 'aagdpr/ajax/libs/datatables/1.10.21/js/dataTables.bootstrap.min.js' %}" integrity="sha512-F0E+jKGaUC90odiinxkfeS3zm9uUT1/lpusNtgXboaMdA3QFMUez0pBmAeXGXtGxoGZg3bLmrkSkbK1quua4/Q=="></script>
<!-- End Datatables-js from aa-gdpr -->
