{% load static %}
<!-- Start Datatables-css from aa-gdpr -->
<link rel="stylesheet" type="text/css" href="{% static 'aagdpr/ajax/libs/datatables/1.10.21/css/dataTables.bootstrap.min.css' %}" integrity="sha512-BMbq2It2D3J17/C7aRklzOODG1IQ3+MHw3ifzBHMBwGO/0yUqYmsStgBjI0z5EYlaDEFnvYV7gNYdD3vFLRKsA=="/>
<!-- End Datatables-css from aa-gdpr -->
