{% load static %}
<!-- Start jQuery UI JS from aa-gdpr -->
<script src="{% static 'aagdpr/ajax/libs/jquery-ui/1.12.1/js/jquery-ui.min.js' %}" integrity="sha512-uto9mlQzrs59VwILcLiRYeLKPPbS/bT71da/OEBYEwcdNUk8jYIy+D176RYoop1Da+f9mvkYrmj5MCLZWEtQuA==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<!-- End jQuery UI JS from aa-gdpr -->
