{% load static %}
<!-- Start Clipboard.js js from aa-gdpr -->
<script type="application/javascript" src="{% static 'aagdpr/ajax/libs/clipboard.js/2.0.8/clipboard.min.js' %}" integrity="sha512-sIqUEnRn31BgngPmHt2JenzleDDsXwYO+iyvQ46Mw6RL+udAUZj2n/u/PGY80NxRxynO7R9xIGx5LEzw4INWJQ=="></script>
<!-- End Clipboard.js js from aa-gdpr -->
